@@ -1,6 +1,5 @@
 ## File Name: tam_mml_create_nodes.R
-## File Version: 0.14
-## File Last Change: 2017-09-14 19:38:50
+## File Version: 0.23
 
 tam_mml_create_nodes <- function(snodes, nodes, ndim, QMC,
 		skillspace="normal", theta.k=NULL)
@@ -24,13 +23,14 @@ tam_mml_create_nodes <- function(snodes, nodes, ndim, QMC,
 	if ( ( skillspace == "discrete") & ( ! is.null(theta.k) ) ){	  
 		theta <- as.matrix( theta.k )
 		nnodes <- nrow(theta)
+		ntheta <- nnodes
 	}	
 	
 	#----------------------------------------
     #--- numeric integration
     if ( ( snodes == 0 ) & do_numeric ){ 
-		theta <- tam_mml_create_nodes_multidim_nodes(nodes=nodes, ndim=ndim)	
-		if ( ( skillspace != "normal") & ( ! is.null(theta.k) ) ){	  
+		theta <- tam_mml_create_nodes_multidim_nodes(nodes=nodes, ndim=ndim)
+		if ( ( skillspace != "normal") & ( ! is.null(theta.k) ) ){
 			theta <- as.matrix( theta.k )
 			nnodes <- nrow(theta)
 		}		
@@ -39,7 +39,8 @@ tam_mml_create_nodes <- function(snodes, nodes, ndim, QMC,
 		# grid width for calculating the deviance
 		thetawidth <- diff(theta[,1] )
 		thetawidth <- ( ( thetawidth[ thetawidth > 0 ])[1] )^ndim 
-		nnodes <- nrow(theta)		
+		nnodes <- nrow(theta)
+		ntheta <- nnodes		
     } 
 	#----------------------------------------
     #--- stochastic integration
@@ -53,15 +54,17 @@ tam_mml_create_nodes <- function(snodes, nodes, ndim, QMC,
 				theta0.samp <- theta0.samp[ order(theta0.samp[,1]) , ]
 			}
 		} else {
-			theta0.samp <- matrix( CDM::CDM_rmvnorm( snodes , mean = rep(0,ndim) , 
-                                        sigma = diag(1,ndim ) )	, nrow= snodes , ncol=ndim )			
+			theta0.samp <- matrix( CDM::CDM_rmvnorm( snodes, mean = rep(0,ndim) , 
+                                        sigma = diag(1,ndim)), nrow= snodes, ncol=ndim )
 		}
-		nnodes <- nrow(theta0.samp)
+		nnodes <- snodes
+		theta <- matrix( theta0.samp , nrow=snodes, ncol=ndim)
+		ntheta <- snodes
     }
 	#---- OUTPUT	
 	res <- list( theta=theta, theta2=theta2, thetawidth=thetawidth,
 					theta0.samp=theta0.samp, thetasamp.density=thetasamp.density,
 					nodes=nodes, snodes=snodes, QMC=QMC, nnodes=nnodes,
-					theta.k=theta.k)
+					theta.k=theta.k, ntheta=ntheta)			
 	return(res)	
 }
